==> zio-aws-fsx_2.12-5.17.124.3-sources.jar: zio/aws/fsx/model/AssociateFileSystemAliasesResponse.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateFileSystemAliasesResponse(
    aliases: Option[Iterable[zio.aws.fsx.model.Alias]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse = {
    import AssociateFileSystemAliasesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
      .builder()
      .optionallyWith(
        aliases.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.aliases)
      .build()
  }
  def asReadOnly
      : zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly =
    zio.aws.fsx.model.AssociateFileSystemAliasesResponse.wrap(buildAwsValue())
}
object AssociateFileSystemAliasesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.AssociateFileSystemAliasesResponse =
      zio.aws.fsx.model.AssociateFileSystemAliasesResponse(
        aliases.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def aliases: Option[List[zio.aws.fsx.model.Alias.ReadOnly]]
    def getAliases: ZIO[Any, AwsError, List[zio.aws.fsx.model.Alias.ReadOnly]] =
      AwsError.unwrapOptionField("aliases", aliases)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ) extends zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly {
    override val aliases: Option[List[zio.aws.fsx.model.Alias.ReadOnly]] = scala
      .Option(impl.aliases())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.fsx.model.Alias.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ): zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-fsx_2.13-5.17.164.1-sources.jar: zio/aws/fsx/model/AssociateFileSystemAliasesResponse.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateFileSystemAliasesResponse(
    aliases: Optional[Iterable[zio.aws.fsx.model.Alias]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse = {
    import AssociateFileSystemAliasesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
      .builder()
      .optionallyWith(
        aliases.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.aliases)
      .build()
  }
  def asReadOnly
      : zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly =
    zio.aws.fsx.model.AssociateFileSystemAliasesResponse.wrap(buildAwsValue())
}
object AssociateFileSystemAliasesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.AssociateFileSystemAliasesResponse =
      zio.aws.fsx.model.AssociateFileSystemAliasesResponse(
        aliases.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def aliases: Optional[List[zio.aws.fsx.model.Alias.ReadOnly]]
    def getAliases: ZIO[Any, AwsError, List[zio.aws.fsx.model.Alias.ReadOnly]] =
      AwsError.unwrapOptionField("aliases", aliases)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ) extends zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly {
    override val aliases: Optional[List[zio.aws.fsx.model.Alias.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.aliases())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.fsx.model.Alias.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.AssociateFileSystemAliasesResponse
  ): zio.aws.fsx.model.AssociateFileSystemAliasesResponse.ReadOnly =
    new Wrapper(impl)
}
